@@ -171,6 +171,17 @@
         <translation>Kamerafehler</translation>
     </message>
 </context>
+<context>
+    <name>DSCameraSession</name>
+    <message>
+        <source>Camera not ready for capture</source>
+        <translation>Die Kamera ist nicht aufnahmebereit</translation>
+    </message>
+    <message>
+        <source>Could not save image to file.</source>
+        <translation>Das Bild konnte nicht in eine Datei gespeichert werden.</translation>
+    </message>
+</context>
 <context>
     <name>MFPlayerSession</name>
     <message>
@@ -262,21 +273,6 @@
         <translation>Playback konnte nicht gestartet werden</translation>
     </message>
 </context>
-<context>
-    <name>PLSParser</name>
-    <message>
-        <source>Error parsing playlist: %1, expected count = %2</source>
-        <translation>Fehler beim Auswerten der Abspielliste %1, erwartete Anzahl = %2</translation>
-    </message>
-    <message>
-        <source>Error parsing playlist at line[%1], expected version = 2</source>
-        <translation>Fehler beim Auswerten der Abspielliste bei Zeile [%1], erwartete Version = 2</translation>
-    </message>
-    <message>
-        <source>Error parsing playlist at line[%1]:%2</source>
-        <translation>Fehler beim Auswerten der Abspielliste bei Zeile [%1]:%2</translation>
-    </message>
-</context>
 <context>
     <name>QAndroidAudioEncoderSettingsControl</name>
     <message>
@@ -436,10 +432,6 @@
 </context>
 <context>
     <name>QGstreamerPlayerControl</name>
-    <message>
-        <source>Attempting to play invalid Qt resource</source>
-        <translation>Es wurde versucht, eine ungültige Qt-Ressource abzuspielen</translation>
-    </message>
     <message>
         <source>Attempting to play invalid user stream</source>
         <translation>Es wurde versucht, einen ungültigen Nutzer-Datenstrom abzuspielen</translation>
@@ -484,6 +476,10 @@
 </context>
 <context>
     <name>QMediaPlayer</name>
+    <message>
+        <source>Attempting to play invalid Qt resource</source>
+        <translation>Es wurde versucht, eine ungültige Qt-Ressource abzuspielen</translation>
+    </message>
     <message>
         <source>The QMediaPlayer object does not have a valid service</source>
         <translation>Das QMediaPlayer-Objekt hat keinen gültigen Dienst</translation>
@@ -534,6 +530,10 @@
         <source>CameraImageProcessing is provided by Camera</source>
         <translation>CameraImageProcessing wird von Camera bereitgestellt</translation>
     </message>
+    <message>
+        <source>CameraViewfinder is provided by Camera</source>
+        <translation>CameraViewfinder wird von Camera bereitgestellt</translation>
+    </message>
 </context>
 <context>
     <name>QPlaylistFileParser</name>
@@ -557,4 +557,19 @@
         <translation>Leere Datei angegeben</translation>
     </message>
 </context>
+<context>
+    <name>QWinRTCameraImageCaptureControl</name>
+    <message>
+        <source>Camera not ready</source>
+        <translation>Kamera nicht bereit</translation>
+    </message>
+    <message>
+        <source>Invalid photo data length.</source>
+        <translation>Ungültige Länge der Bilddaten.</translation>
+    </message>
+    <message>
+        <source>Image saving failed</source>
+        <translation>Das Speichern des Bildes schlug fehl</translation>
+    </message>
+</context>
 </TS>
