@@ -1,11 +1,11 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="ru_RU">
+<TS version="2.1" language="ru_RU">
 <context>
-    <name>AudioCaptureSession</name>
+    <name>AudioContainerControl</name>
     <message>
-        <source>RAW file format</source>
-        <translation>Формат файла RAW</translation>
+        <source>RAW (headerless) file format</source>
+        <translation>Формат файла RAW (без заголовка)</translation>
     </message>
     <message>
         <source>WAV file format</source>
@@ -15,8 +15,8 @@
 <context>
     <name>AudioEncoderControl</name>
     <message>
-        <source>PCM audio data</source>
-        <translation>Аудио-данные PCM</translation>
+        <source>Linear PCM audio data</source>
+        <translation>Аудио-данные Linear PCM</translation>
     </message>
 </context>
 <context>
@@ -159,6 +159,10 @@
         <source>Service has not been started</source>
         <translation>Служба не была запущена</translation>
     </message>
+    <message>
+        <source>Recording permissions are not available</source>
+        <translation>Нет доступа на запись</translation>
+    </message>
 </context>
 <context>
     <name>CameraBinSession</name>
@@ -167,6 +171,17 @@
         <translation>Ошибка камеры</translation>
     </message>
 </context>
+<context>
+    <name>DSCameraSession</name>
+    <message>
+        <source>Camera not ready for capture</source>
+        <translation>Камера не готова к захвату</translation>
+    </message>
+    <message>
+        <source>Could not save image to file.</source>
+        <translation>Не удалось сохранить изображение в файл.</translation>
+    </message>
+</context>
 <context>
     <name>MFPlayerSession</name>
     <message>
@@ -259,30 +274,79 @@
     </message>
 </context>
 <context>
-    <name>PLSParser</name>
+    <name>QAndroidAudioEncoderSettingsControl</name>
     <message>
-        <source>Error parsing playlist: %1, expected count = %2</source>
-        <translation>Ошибка разбора списка воспроизведения: %1, ожидается count = %2</translation>
+        <source>Adaptive Multi-Rate Narrowband (AMR-NB) audio codec</source>
+        <translation>Звуковой кодек адаптивно-многочастотно-узкополосный (AMR-NB)</translation>
     </message>
     <message>
-        <source>Error parsing playlist at line[%1], expected version = 2</source>
-        <translation>Ошибка разора списка воспроизведения в строке %1, ожидается версия = 2</translation>
+        <source>Adaptive Multi-Rate Wideband (AMR-WB) audio codec</source>
+        <translation>Звуковой кодек адаптивно-многочастотно-широкополосный (AMR-WB)</translation>
     </message>
     <message>
-        <source>Error parsing playlist at line[%1]:%2</source>
-        <translation>Ошибка разбора списка воспроизведения в строке %1: %2</translation>
+        <source>AAC Low Complexity (AAC-LC) audio codec</source>
+        <translation>Звуковой кодек AAC низкой сложности (AAC-LC)</translation>
+    </message>
+</context>
+<context>
+    <name>QAndroidCameraSession</name>
+    <message>
+        <source>Camera cannot be started without a viewfinder.</source>
+        <translation>Невозможно запустить камеру без видоискателя.</translation>
     </message>
     <message>
-        <source>File%1</source>
-        <translation>Файл%1</translation>
+        <source>Camera not ready</source>
+        <translation>Камера не готова</translation>
     </message>
     <message>
-        <source>Title%1</source>
-        <translation>Название%1</translation>
+        <source>Drive mode not supported</source>
+        <extracomment>Drive mode is the camera&apos;s shutter mode, for example single shot, continuos exposure, etc.</extracomment>
+        <translation>Режим множественной съёмки не поддерживается</translation>
     </message>
     <message>
-        <source>Length%1</source>
-        <translation>Длина%1</translation>
+        <source>Could not open destination file: %1</source>
+        <translation>Не удалось открыть выходной файл: %1</translation>
+    </message>
+</context>
+<context>
+    <name>QAndroidImageEncoderControl</name>
+    <message>
+        <source>JPEG image</source>
+        <translation>Изображение JPEG</translation>
+    </message>
+</context>
+<context>
+    <name>QAndroidMediaContainerControl</name>
+    <message>
+        <source>MPEG4 media file format</source>
+        <translation>Формат файла MPEG4</translation>
+    </message>
+    <message>
+        <source>3GPP media file format</source>
+        <translation>Фомат файла 3GPP</translation>
+    </message>
+    <message>
+        <source>AMR NB file format</source>
+        <translation>Формат файла AMR NB</translation>
+    </message>
+    <message>
+        <source>AMR WB file format</source>
+        <translation>Формат файла AMR WB</translation>
+    </message>
+</context>
+<context>
+    <name>QAndroidVideoEncoderSettingsControl</name>
+    <message>
+        <source>H.263 compression</source>
+        <translation>Сжатие H.263</translation>
+    </message>
+    <message>
+        <source>H.264 compression</source>
+        <translation>Сжатие H.264</translation>
+    </message>
+    <message>
+        <source>MPEG-4 SP compression</source>
+        <translation>Сжатие MPEG-4 SP</translation>
     </message>
 </context>
 <context>
@@ -368,10 +432,6 @@
 </context>
 <context>
     <name>QGstreamerPlayerControl</name>
-    <message>
-        <source>Attempting to play invalid Qt resource</source>
-        <translation>Попытка воспроизвести неверный ресурс Qt</translation>
-    </message>
     <message>
         <source>Attempting to play invalid user stream</source>
         <translation>Попытка воспроизвести неверный пользовательский поток</translation>
@@ -416,6 +476,10 @@
 </context>
 <context>
     <name>QMediaPlayer</name>
+    <message>
+        <source>Attempting to play invalid Qt resource</source>
+        <translation>Попытка воспроизвести неверный ресурс Qt</translation>
+    </message>
     <message>
         <source>The QMediaPlayer object does not have a valid service</source>
         <translation>Объект QMediaPlayer не имеет подходящей службы</translation>
@@ -466,16 +530,13 @@
         <source>CameraImageProcessing is provided by Camera</source>
         <translation>CameraImageProcessing предоставляется камерой</translation>
     </message>
-</context>
-<context>
-    <name>QPlaylistFileParser</name>
     <message>
-        <source>%1 does not exist</source>
-        <translation>%1 не существует</translation>
+        <source>CameraViewfinder is provided by Camera</source>
+        <translation>CameraViewfinder предоставляется камерой</translation>
     </message>
 </context>
 <context>
-    <name>QPlaylistFileParserPrivate</name>
+    <name>QObject</name>
     <message>
         <source>%1 playlist type is unknown</source>
         <translation>Неизвестный формат списка воспроизведения %1</translation>
@@ -489,4 +550,26 @@
         <translation>Предоставлен пустой файл</translation>
     </message>
 </context>
+<context>
+    <name>QPlaylistFileParser</name>
+    <message>
+        <source>%1 does not exist</source>
+        <translation>%1 не существует</translation>
+    </message>
+</context>
+<context>
+    <name>QWinRTCameraImageCaptureControl</name>
+    <message>
+        <source>Camera not ready</source>
+        <translation>Камера не готова</translation>
+    </message>
+    <message>
+        <source>Invalid photo data length.</source>
+        <translation>Неверная длина данных фотографии.</translation>
+    </message>
+    <message>
+        <source>Image saving failed</source>
+        <translation>Не удалось сохранить изображение</translation>
+    </message>
+</context>
 </TS>
